EasyScaleTransition class

A concrete implementation of CustomTransitionModule for a scale transition animation.

Inheritance

Constructors

EasyScaleTransition()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildDialogRoute(Widget child, Duration duration, Curve curve, BuildContext context) → DialogRoute
override
buildPageRoute(Widget child, Duration duration, Curve curve) → PageRoute
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited