TransitionEasy class

Constructors

TransitionEasy({required Widget child, required CustomTransitionModule customTransitionModule, Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.linear})
Creates a custom transition module for handling page route transitions.

Properties

child → Widget
final
curve → Curve
final
customTransitionModule → CustomTransitionModule
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildDialogRoute(BuildContext context) → DialogRoute
Returns the appropriate DialogRoute based on the transition type.
buildPageRoute() → PageRoute
Returns the appropriate PageRoute based on the transition type.
buildRoute(BuildContext context, bool isDialog) → Route
Returns the appropriate Route based on the transition type.
dynamicNavigation(BuildContext context, {bool isDialog = false}) → Future<void>
Executes a dynamic navigation with the specified transition type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited